@@ -15,7 +15,7 @@ from typing import Any, Dict, List, NewType, Optional, Tuple, Union  # pylint: d
 
 from dataclasses_json import DataClassJsonMixin
 
-from annofabapi.models import AccountAuthority, OrganizationMemberRole, OrganizationMemberStatus, PricePlan
+from annofabapi.models import KeyLayout, Lang, OrganizationMemberRole, OrganizationMemberStatus, PricePlan
 
 
 @dataclass
@@ -55,37 +55,37 @@ class MyAccount(DataClassJsonMixin):
     """ """
 
     account_id: str
-    """"""
+    """アカウントID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
     user_id: str
-    """"""
+    """ユーザーID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
     username: str
-    """"""
+    """ユーザー名"""
 
     email: str
-    """"""
+    """メールアドレス"""
 
-    lang: str
+    lang: Lang
     """"""
 
     biography: Optional[str]
     """人物紹介、略歴。  この属性は、AnnoFab外の所属先や肩書などを表すために用います。 AnnoFab上の「複数の組織」で活動する場合、本籍を示すのに便利です。 """
 
-    keylayout: str
+    keylayout: KeyLayout
     """"""
 
-    authority: AccountAuthority
-    """"""
+    authority: str
+    """システム内部用のプロパティ"""
 
     is_external_account: bool
-    """[外部アカウントだけで作成したアカウント](/docs/faq/#v1u344)の場合true。  外部アカウント連携していないAnnoFabアカウントや、後から[外部アカウントとの紐付け](/docs/faq/#yyyub0)をしたAnnoFabアカウントの場合false。 """
+    """[外部アカウントだけで作成したアカウント](/docs/faq/#v1u344)の場合はtrue。  外部アカウント連携していないAnnoFabアカウントや、後から[外部アカウントとの紐付け](/docs/faq/#yyyub0)をしたAnnoFabアカウントの場合はfalse。 """
 
-    updated_datetime: Optional[str]
-    """"""
+    updated_datetime: str
+    """更新日時"""
 
     reset_requested_email: Optional[str]
-    """"""
+    """システム内部用のプロパティ"""
 
     errors: List[str]
-    """"""
+    """システム内部用のプロパティ"""
