@@ -26,10 +26,10 @@ class OrganizationMember(DataClassJsonMixin):
     """組織ID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
     account_id: str
-    """"""
+    """アカウントID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
     user_id: str
-    """"""
+    """ユーザーID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
     username: str
     """"""
