@@ -271,8 +271,9 @@ class Wrapper:
             FutureWarning,
             stacklevel=2,
         )
-        content, _ = self.api.get_archive_full_with_pro_id(project_id)
-        url = content["url"]
+        # 2022/01時点でレスポンスのcontent-typeが"text/plain"なので、contentの型がdictにならない。したがって、Locationヘッダを参照する。
+        _, response = self.api.get_archive_full_with_pro_id(project_id)
+        url = response.headers["Location"]
         response2 = self._download(url, dest_path)
         logger.info(
             "FullアノテーションZIPファイルをダウンロードしました。 :: project_id='%s', Last-Modified='%s', file='%s'",
@@ -1731,16 +1732,13 @@ class Wrapper:
     #########################################
     # Public Method : Task
     #########################################
-    def initiate_tasks_generation_by_csv(
-        self, project_id: str, csvfile_path: str, query_params: Optional[Dict[str, Any]] = None
-    ) -> Dict[str, Any]:
+    def initiate_tasks_generation_by_csv(self, project_id: str, csvfile_path: str) -> Dict[str, Any]:
         """
         タスクID,入力データ名,入力データID」を1行毎に指定したCSVを使って、タスクを生成する
 
         Args:
             project_id: プロジェクトID
             csvfile_path: CSVファイルのパス
-            query_params: `initiate_tasks_generation` メソッドに渡す`query_params`
 
         Returns:
             `initiate_tasks_generation` APIのContent
@@ -1753,7 +1751,7 @@ class Wrapper:
             "task_generate_rule": {"_type": "ByInputDataCsv", "csv_data_path": s3_path},
             "project_last_updated_datetime": project_last_updated_datetime,
         }
-        return self.api.initiate_tasks_generation(project_id, request_body=request_body, query_params=query_params)[0]
+        return self.api.initiate_tasks_generation(project_id, request_body=request_body)[0]
 
     def get_task_or_none(self, project_id: str, task_id: str) -> Optional[Task]:
         """
@@ -2250,7 +2248,11 @@ class Wrapper:
 
             elif job["job_status"] == JobStatus.FAILED.value:
                 logger.info(
-                    "project_id='%s', job_id='%s', job_type='%s' のジョブが失敗しました。", project_id, job_id, job_type.value
+                    "project_id='%s', job_id='%s', job_type='%s' のジョブが失敗しました。:: errors='%s'",
+                    project_id,
+                    job_id,
+                    job_type.value,
+                    job["errors"],
                 )
                 return JobStatus.FAILED
 
